// CSplitterLeftView.h : Schnittstelle der Klasse CSplitterLeftView
//


#pragma once

#include "CSplitterDoc.h"

/**\brief FormView im linken Fenster des geteilten Hauptfensters.
 * 
 * Die View enthlt ein Textfeld mit dem aktuellen
 * Text aus dem Document sowie einen Button um die aktuelle Textfeld-Eingabe
 * in das Document zu bernehmen.
 */
class CSplitterLeftView : public CFormView
{
protected: // Nur aus Serialisierung erstellen
	/**Protected Konstruktor.
	 * Keine besondere Logik.
	 */
	CSplitterLeftView();
	DECLARE_DYNCREATE(CSplitterLeftView)

public:
	/**Resourcen-ID des Fensters. */
	enum{ IDD = IDD_SPLITTERLEFTVIEW };

// Attribute
public:
	/**Typsicheres Abrufen der Document-Klasse.
	 * @return Die auf CSplitterDoc gecastete Rckgabe aus der Basisklassenmethode.
	 */
	CSplitterDoc* GetDocument() const;

// Vorgnge
public:

// berschreibungen
public:
	/**Initialisierung des Fensters vor dem Erzeugen.
	 * Hier passiert nichts.
	 * @param cs Mittels dieser CREATESTRUCT kann das Layout des Fensters gendert werden.
	 * @return 0 bei Fehlern, jeder andere Wert im Erfolgsfall.
	 */
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
protected:
	/**Datenaustausch zwischen Eingabefeldern und Variablen.
	 * Hier werden Textfeld und Variable "m_sText" abgeglichen.
	 * @param pDX Klasse fr den Datenaustausch und die Validierung.
	 */
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV-Untersttzung
	/**Erstmaliges Update nachdem die View mit einem Document
	 * verknpft wurde.
	 * Hier: keine besondere Logik.
	 */
	virtual void OnInitialUpdate(); // Erster Aufruf nach Erstellung

// Implementierung
public:
	/**Destruktor. Nichts besonderes.
	 */
	virtual ~CSplitterLeftView();
#ifdef _DEBUG
	/**Debug-Modus: Prfen ob View gltig ist.
	 * Ruft nur Parentklassen-Methode auf.
	 */
	virtual void AssertValid() const;
	/**Debug-Modus: Klasse fr Konsolenausgabe dumpen
	 * Ruft nur Parentklassen-Methode auf.
	 * @param dc diagnostic dump context
	 */
	virtual void Dump(CDumpContext& dc) const;
#endif

protected:

// Generierte Funktionen fr die Meldungstabellen
protected:
	DECLARE_MESSAGE_MAP()
private:
	/**Der Wert aus dem Textfeld der linken View.
	 */
	CString m_sText;
	/**Auf den Button "Nach rechts" wird geklickt.
	 * DataExchange aufrufen, dadurch wird der Inhalt des Textfelds
	 * ins Document geschrieben. Anschlieend alle Views ber eine
	 * Document-nderung benachrichtigen.
	 */
	afx_msg void OnBnClickedButtonLeft();
protected:
	/**Update der View nach einer nderung im Document.
	 * Wird unter anderem von der rechten View nach Klick auf den Button "Nach Links" 
	 * aufgerufen.
	 * @param pSender Sendende View. Wenn NULL dann geht das Update an alle Views.
	 * @param lHint Weitere, benutzerspezifische Informationen ber das Update.
     * @param pHint Weitere, benutzerspezifische Informationen ber das Update.
	 */
	virtual void OnUpdate(CView* pSender, LPARAM lHint, CObject* pHint);
};

#ifndef _DEBUG  // Debugversion in CSplitterLeftView.cpp
inline CSplitterDoc* CSplitterLeftView::GetDocument() const
   { return reinterpret_cast<CSplitterDoc*>(m_pDocument); }
#endif

